@@ -18,6 +18,8 @@ import qtawesome as qta
 import QOpenScienceFramework.connection as osf
 # Fileinspector for determining filetypes
 import fileinspector
+# For better time functions
+import arrow
 # For presenting numbers in human readible formats
 import humanize
 # Unix style filename matching
@@ -95,7 +97,8 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		self.setWindowIcon(osf_icon)
 
 		# Set column labels
-		self.setHeaderLabels(["Name","Kind","Size"])
+		self.setHeaderLabels([_("Name"), _("Kind"), _("Size"), _("Created"), 
+			_("Modified")])
 		self.setColumnWidth(0,300)
 
 		# Event handling
@@ -427,12 +430,14 @@ class ProjectTree(QtWidgets.QTreeWidget):
 		time depending on the number of projects that the user has, so it is 
 		recommended to use a partial refresh (refresh_children_of_node), wherever
 		you can. """
+		
 		# If tree is already refreshing, don't start again, as this will result
 		# in a crash
-		if self.isRefreshing == True:
+		if self.isRefreshing:
 			return
 		# Set flag that tree is currently refreshing
 		self.isRefreshing = True
+		
 		# Save current item selection to restore it after refresh
 		current_item = self.currentItem()
 		if current_item:
@@ -484,7 +489,21 @@ class ProjectTree(QtWidgets.QTreeWidget):
 
 		values = [name, kind]
 		if "size" in data["attributes"] and data["attributes"]["size"]:
-			values += [humanize.naturalsize(data["attributes"]["size"])]
+			values += [ humanize.naturalsize(data["attributes"]["size"]) ]
+		else:
+			values += ['']
+
+		if "date_created" in data["attributes"]:
+			cArrow = arrow.get(data["attributes"]["date_created"]).to('local')
+			values += [ cArrow.format('YYYY-MM-DD') ]
+		else:
+			values += ['']
+
+		if "date_modified" in data["attributes"]:
+			mArrow = arrow.get(data["attributes"]["date_modified"]).to('local')
+			values += [ mArrow.format('YYYY-MM-DD') ]
+		else:
+			values += ['']
 
 		# Create item
 		item = QtWidgets.QTreeWidgetItem(parent, values)
@@ -651,7 +670,8 @@ class ProjectTree(QtWidgets.QTreeWidget):
 	def handle_login(self):
 		""" Callback function for EventDispatcher when a login event is detected. """
 		self.active_requests = []
-		self.refresh_contents()
+		if not self.isRefreshing:
+			self.refresh_contents()
 
 	def handle_logout(self):
 		""" Callback function for EventDispatcher when a logout event is detected. """
